@@ -1,4 +1,5 @@
 #' @keywords internal
+#' @import checkmate
 #' @import data.table
 #' @importFrom httr2 req_body_json
 #' @importFrom httr2 req_error
@@ -13,7 +14,10 @@
 #' @importFrom httr2 resp_body_string
 #' @importFrom httr2 resp_body_xml
 #' @importFrom httr2 resp_content_type
+#' @importFrom httr2 resp_status
+#' @importFrom httr2 resp_url
 #' @importFrom stats na.omit setNames
 "_PACKAGE"
 
-utils::globalVariables(c("name", "Date", "decimals", "value", "duration"))
+the <- new.env(parent = emptyenv())
+the$col_order <- c("date", "key", "value", "freq", "title", "description")
