@@ -17,8 +17,7 @@ test_that("snb_data input validation works", {
 test_that("parse_snb_data() works", {
   body <- readRDS(test_path("fixtures", "snb-data.rds"))
   actual <- parse_snb_data(body)
-  expect_data_table(actual)
-  expect_gt(nrow(actual), 0L)
+  expect_data_table(actual, min.rows = 1L)
   expect_match(actual$key, "^EPB@SNB.rendopar")
   expect_date(actual$date)
 })
